#include "./controller/widget/widget_control.h"

#include <imgui.h>

#include "./core/scene.h"
#include "./widget_node_view.h"

namespace Splash
{

/*************/
void GuiControl::render()
{
    // Node view
    if (!_nodeView)
    {
        auto scene = dynamic_cast<Scene*>(_root);
        auto nodeView = std::make_shared<GuiNodeView>(scene, "Nodes");
        _nodeView = std::dynamic_pointer_cast<GuiWidget>(nodeView);
    }
    _nodeView->render();

    // Node configuration
    // Select the object the control
    int index = 0;
    std::string clickedNode = std::dynamic_pointer_cast<GuiNodeView>(_nodeView)->getClickedNode(); // Used to set the object

    const auto objectNames = getObjectList();
    if (!clickedNode.empty())
    {
        // Update the object name
        for (const auto& name : objectNames)
        {
            if (name == clickedNode)
            {
                _targetIndex = index;
                break;
            }
            index++;
        }

        if (_targetIndex >= 0)
        {
            if (objectNames.size() <= static_cast<uint32_t>(_targetIndex))
                return;
            _targetObjectName = objectNames[_targetIndex];
        }
    }
    else if (!_targetObjectName.empty())
    {
        // Check the object still exists
        if (std::find(objectNames.begin(), objectNames.end(), _targetObjectName) == objectNames.end())
            _targetObjectName.clear();
    }
}

/*************/
int GuiControl::updateWindowFlags()
{
    ImGuiWindowFlags flags = 0;
    if (_nodeView)
        flags |= _nodeView->updateWindowFlags();
    return flags;
}

} // namespace Splash
