/*
 * Copyright (C) 2017 Splash authors
 *
 * This file is part of Splash.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Splash is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Splash.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * @widget_textures.h
 * The Texture widget, to view and control textures
 */

#ifndef SPLASH_WIDGET_TEXTURES_H
#define SPLASH_WIDGET_TEXTURES_H

#include "./widget.h"

namespace Splash
{

/*************/
class GuiTextures : public GuiWidget
{
  public:
    GuiTextures(Scene* scene, const std::string& name)
        : GuiWidget(scene, name)
    {
    }
    void render() final;
    inline std::vector<std::string> getActiveObjectNames() const final
    {
        if (!_selectedObjectName.empty())
            return {_selectedObjectName};
        return {};
    }

  private:
    bool _hideNonSavable{true};
    GraphObject::Category _selectedCategory{GraphObject::Category::TEXTURE};
    std::string _selectedObjectName;
    float _zoomRatio = 1.f;

    /**
     * Get the correct getter function to grab all the texture
     * of the given category
     * \param category Texture category
     * \return A vector of all the objects, as Textures
     */
    std::function<std::vector<std::shared_ptr<Texture>>()> getTextureLister(GraphObject::Category category);
};

} // namespace Splash

#endif
