#include "./utils/osutils.h"

#include <filesystem>

#if HAVE_WINDOWS
#include <windows.h>
#endif

namespace Splash::Utils
{

/*************/
std::string getCurrentExecutablePath()
{
    std::string currentExePath = "";
#if HAVE_LINUX
    auto pid = getpid();
    auto procExe = "/proc/" + std::to_string(pid) + "/exe";
    char* realPath = realpath(procExe.c_str(), nullptr);
    if (realPath)
    {
        currentExePath = std::string(realPath);
        free(realPath);
    }
#elif HAVE_WINDOWS
    currentExePath.resize(MAX_PATH, '\0');
    GetModuleFileName(nullptr, currentExePath.data(), static_cast<DWORD>(currentExePath.max_size()));
#endif
    return currentExePath;
}

/*************/
std::string getHomePath()
{
#if HAVE_LINUX
    if (char* homeEnv = std::getenv("HOME"); homeEnv != nullptr)
        return std::string(homeEnv);

    struct passwd* pw = getpwuid(getuid());
    return std::string(pw->pw_dir);
#elif HAVE_WINDOWS
    if (char* homeEnv = std::getenv("USERPROFILE"); homeEnv != nullptr)
        return std::string(homeEnv);
    return "";
#endif
}

/*************/
std::string getAssetsPath()
{
#if WITH_PORTABLE
    const auto assetPath = std::filesystem::path(getCurrentExecutablePath() + "/../" + DATADIR);
    return assetPath.lexically_normal().string();
#else
    return std::string(DATADIR);
#endif
}

} // namespace Splash::Utils
